@@ -1,22 +1,8 @@
 /*
- * Copyright 2014 Ivan Cukic <ivan.cukic@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2014 Ivan Cukic <ivan.cukic@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "Database.h"
 
@@ -24,24 +10,20 @@
 #include <common/database/schema/ResourcesDatabaseSchema.h>
 
 #include <QSqlDatabase>
-#include <QSqlQuery>
 #include <QSqlField>
 #include <QSqlError>
 #include <QSqlDriver>
 #include <QThread>
 #include <QDebug>
 
-#include <memory>
 #include <mutex>
 #include <map>
 
+#include "kactivities-stats-logsettings.h"
+
 namespace Common {
 
 namespace {
-#ifdef QT_DEBUG
-    QString lastExecutedQuery;
-#endif
-
     std::mutex databases_mutex;
 
     struct DatabaseInfo {
@@ -71,11 +53,11 @@ public:
         : m_open(false)
     {
         m_connectionName =
-                "kactivities_db_resources_"
+                QStringLiteral("kactivities_db_resources_")
                     // Adding the thread number to the database name
                     + QString::number((quintptr)info.thread)
                     // And whether it is read-only or read-write
-                    + (info.openMode == Database::ReadOnly ? "_readonly" : "_readwrite");
+                    + (info.openMode == Database::ReadOnly ? QStringLiteral("_readonly") : QStringLiteral("_readwrite"));
 
         m_database =
             QSqlDatabase::contains(m_connectionName)
@@ -92,7 +74,7 @@ public:
         m_open = m_database.open();
 
         if (!m_open) {
-            qWarning() << "KActivities: Database is not open: "
+            qCWarning(KACTIVITIES_STATS_LOG) << "KActivities: Database is not open: "
                        << m_database.connectionName()
                        << m_database.databaseName()
                        << m_database.lastError();
@@ -105,7 +87,7 @@ public:
 
     ~QSqlDatabaseWrapper()
     {
-        qDebug() << "Closing SQL connection: " << m_connectionName;
+        qCDebug(KACTIVITIES_STATS_LOG) << "Closing SQL connection: " << m_connectionName;
     }
 
     QSqlDatabase &get()
@@ -201,10 +183,10 @@ Database::Ptr Database::instance(Source source, OpenMode openMode)
     // Maybe we should use the write-ahead log
     auto walResult = ptr->pragma(QStringLiteral("journal_mode = WAL"));
 
-    if (walResult != "wal") {
-        qWarning("KActivities: Database can not be opened in WAL mode. Check the "
+    if (walResult != QLatin1String("wal")) {
+        qCWarning(KACTIVITIES_STATS_LOG) << "KActivities: Database can not be opened in WAL mode. Check the "
                  "SQLite version (required >3.7.0). And whether your filesystem "
-                 "supports shared memory");
+                 "supports shared memory";
 
         return nullptr;
     }
@@ -213,7 +195,7 @@ Database::Ptr Database::instance(Source source, OpenMode openMode)
     // it reaches 400k, not 4M as is default
     ptr->setPragma(QStringLiteral("wal_autocheckpoint = 100"));
 
-    qDebug() << "KActivities: Database connection: " << ptr->d->database->connectionName()
+    qCDebug(KACTIVITIES_STATS_LOG) << "KActivities: Database connection: " << ptr->d->database->connectionName()
         << "\n    query_only:         " << ptr->pragma(QStringLiteral("query_only"))
         << "\n    journal_mode:       " << ptr->pragma(QStringLiteral("journal_mode"))
         << "\n    wal_autocheckpoint: " << ptr->pragma(QStringLiteral("wal_autocheckpoint"))
@@ -236,32 +218,9 @@ QSqlQuery Database::createQuery() const
     return d->query();
 }
 
-QString Database::lastQuery() const
+QSqlQuery Database::execQuery(const QString &query) const
 {
-#ifdef QT_DEBUG
-    return lastExecutedQuery;
-#endif
-    return QString();
-}
-
-QSqlQuery Database::execQuery(const QString &query, bool ignoreErrors) const
-{
-#ifdef QT_NO_DEBUG
-    Q_UNUSED(ignoreErrors);
     return d->query(query);
-#else
-    auto result = d->query(query);
-
-    lastExecutedQuery = query;
-
-    if (!ignoreErrors && result.lastError().isValid()) {
-        qWarning() << "SQL: "
-                   << "\n    error: " << result.lastError()
-                   << "\n    query: " << query;
-    }
-
-    return result;
-#endif
 }
 
 QSqlQuery Database::execQueries(const QStringList &queries) const
@@ -282,7 +241,7 @@ void Database::setPragma(const QString &pragma)
 
 QVariant Database::pragma(const QString &pragma) const
 {
-    return value("PRAGMA " + pragma);
+    return value(QStringLiteral("PRAGMA ") + pragma);
 }
 
 QVariant Database::value(const QString &query) const
