@@ -12,7 +12,7 @@
 #include <QSqlError>
 #include <QCoreApplication>
 #include <QList>
-#include <QRegExp>
+#include <QRegularExpression>
 
 // Local
 #include <common/database/Database.h>
@@ -49,7 +49,7 @@ namespace Stats {
 class ResultWatcherPrivate {
 public:
     mutable ActivitiesSync::ConsumerPtr activities;
-    QList<QRegExp> urlFilters;
+    QList<QRegularExpression> urlFilters;
 
     ResultWatcherPrivate(ResultWatcher *parent, Query query)
         : linking(new KAMD_DBUS_CLASS_INTERFACE(Resources/Linking, ResourcesLinking, nullptr))
@@ -132,8 +132,8 @@ public:
         #endif
 
         return kamd::utils::debug_and_return(DEBUG_MATCHERS, " -> returning ",
-            any_of(urlFilters, [&] (const QRegExp &matcher) {
-                return matcher.exactMatch(url);
+            any_of(urlFilters, [&] (const QRegularExpression &matcher) {
+                return matcher.match(url).hasMatch();
             }
         ));
     }
@@ -169,7 +169,15 @@ public:
 
         return kamd::utils::debug_and_return(DEBUG_MATCHERS, " -> returning ",
             any_of(query.types(), [&] (const QString &matcher) {
-                return matcher == ANY_TYPE_TAG || matcher == type;
+                if (matcher == ANY_TYPE_TAG) {
+                    return true;
+                }
+
+                const QString _type = type;
+                return matcher == ANY_TYPE_TAG
+                    || (matcher == FILES_TYPE_TAG && !_type.isEmpty() && _type != QStringLiteral("inode/directory"))
+                    || (matcher == DIRECTORIES_TYPE_TAG && _type == QLatin1String("inode/directory"))
+                    || matcher == type;
             }
         ));
     }
