@@ -1,27 +1,14 @@
 /*
- *   Copyright (C) 2015 Ivan Cukic <ivan.cukic(at)kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License version 2,
- *   or (at your option) any later version, as published by the Free
- *   Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2015 Ivan Cukic <ivan.cukic(at)kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "window.h"
 
 #include "ui_window.h"
-#include "modeltest.h"
 
+#include <QAbstractItemModelTester>
 #include <QAction>
 #include <QListView>
 #include <QDebug>
@@ -304,7 +291,7 @@ void Window::setQuery(const KActivities::Stats::Query &query)
 
     if (QCoreApplication::arguments().contains(QLatin1String("--enable-model-test"))) {
         modelTest.reset();
-        modelTest.reset(new ModelTest(new ResultModel(query)));
+        modelTest.reset(new QAbstractItemModelTester(new ResultModel(query)));
     }
 
     ui->viewResults->setModel(model.get());
@@ -352,7 +339,11 @@ void Window::updateResults()
         Activity(ui->comboActivity->currentText().split(QLatin1Char(','))) |
 
         // And URL filters
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         Url(ui->textUrl->text().split(QLatin1Char(','), QString::SkipEmptyParts)) |
+#else
+        Url(ui->textUrl->text().split(QLatin1Char(','), Qt::SkipEmptyParts)) |
+#endif
 
         // And date filter
         (
